@@ -64,7 +64,6 @@ char *normalize_path(modsec_rec *msr, char *input) {
 
         if(uri->path)   {
             char *Uri = NULL;
-            int bytes = 0;
             /*int i;*/
             char *abs_link = NULL;
             char *filename = NULL;
@@ -388,7 +387,7 @@ int do_hash_method(modsec_rec *msr, char *link, int type)   {
                 case HASH_URL_HREF_HASH_RX:
                     if(em[i]->type == HASH_URL_HREF_HASH_RX)   {
                         rc = msc_regexec_capture(em[i]->param_data, link, strlen(link), ovector, 30, &my_error_msg);
-#ifdef WITH_PCRE2
+#ifndef WITH_PCRE
                         if ((rc == PCRE2_ERROR_MATCHLIMIT) || (rc == PCRE2_ERROR_RECURSIONLIMIT)) {
 #else
                         if ((rc == PCRE_ERROR_MATCHLIMIT) || (rc == PCRE_ERROR_RECURSIONLIMIT)) {
@@ -421,7 +420,7 @@ int do_hash_method(modsec_rec *msr, char *link, int type)   {
                                 msr_log(msr, 4, "%s.", error_msg);
                             return -1;
                         }
-#ifdef WITH_PCRE2
+#ifndef WITH_PCRE
                         if (rc != PCRE2_ERROR_NOMATCH) { /* Match. */
 #else
                         if (rc != PCRE_ERROR_NOMATCH) { /* Match. */
@@ -451,7 +450,7 @@ int do_hash_method(modsec_rec *msr, char *link, int type)   {
                 case HASH_URL_FACTION_HASH_RX:
                     if(em[i]->type == HASH_URL_FACTION_HASH_RX)   {
                         rc = msc_regexec_capture(em[i]->param_data, link, strlen(link), ovector, 30, &my_error_msg);
-#ifdef WITH_PCRE2
+#ifndef WITH_PCRE
                         if ((rc == PCRE2_ERROR_MATCHLIMIT) || (rc == PCRE2_ERROR_RECURSIONLIMIT)) {
 #else
                         if ((rc == PCRE_ERROR_MATCHLIMIT) || (rc == PCRE_ERROR_RECURSIONLIMIT)) {
@@ -484,7 +483,7 @@ int do_hash_method(modsec_rec *msr, char *link, int type)   {
                                 msr_log(msr, 4, "%s.", error_msg);
                             return -1;
                         }
-#ifdef WITH_PCRE2
+#ifndef WITH_PCRE
                         if (rc != PCRE2_ERROR_NOMATCH) { /* Match. */
 #else
                         if (rc != PCRE_ERROR_NOMATCH) { /* Match. */
@@ -514,7 +513,7 @@ int do_hash_method(modsec_rec *msr, char *link, int type)   {
                 case HASH_URL_LOCATION_HASH_RX:
                     if(em[i]->type == HASH_URL_LOCATION_HASH_RX)   {
                         rc = msc_regexec_capture(em[i]->param_data, link, strlen(link), ovector, 30, &my_error_msg);
-#ifdef WITH_PCRE2
+#ifndef WITH_PCRE
                         if ((rc == PCRE2_ERROR_MATCHLIMIT) || (rc == PCRE2_ERROR_RECURSIONLIMIT)) {
 #else
                         if ((rc == PCRE_ERROR_MATCHLIMIT) || (rc == PCRE_ERROR_RECURSIONLIMIT)) {
@@ -547,7 +546,7 @@ int do_hash_method(modsec_rec *msr, char *link, int type)   {
                                 msr_log(msr, 4, "%s.", error_msg);
                             return -1;
                         }
-#ifdef WITH_PCRE2
+#ifndef WITH_PCRE
                         if (rc != PCRE2_ERROR_NOMATCH) { /* Match. */
 #else
                         if (rc != PCRE_ERROR_NOMATCH) { /* Match. */
@@ -577,7 +576,7 @@ int do_hash_method(modsec_rec *msr, char *link, int type)   {
                 case HASH_URL_IFRAMESRC_HASH_RX:
                     if(em[i]->type == HASH_URL_IFRAMESRC_HASH_RX)   {
                         rc = msc_regexec_capture(em[i]->param_data, link, strlen(link), ovector, 30, &my_error_msg);
-#ifdef WITH_PCRE2
+#ifndef WITH_PCRE
                         if ((rc == PCRE2_ERROR_MATCHLIMIT) || (rc == PCRE2_ERROR_RECURSIONLIMIT)) {
 #else
                         if ((rc == PCRE_ERROR_MATCHLIMIT) || (rc == PCRE_ERROR_RECURSIONLIMIT)) {
@@ -610,7 +609,7 @@ int do_hash_method(modsec_rec *msr, char *link, int type)   {
                                 msr_log(msr, 4, "%s.", error_msg);
                             return -1;
                         }
-#ifdef WITH_PCRE2
+#ifndef WITH_PCRE
                         if (rc != PCRE2_ERROR_NOMATCH) { /* Match. */
 #else
                         if (rc != PCRE_ERROR_NOMATCH) { /* Match. */
@@ -640,7 +639,7 @@ int do_hash_method(modsec_rec *msr, char *link, int type)   {
                 case HASH_URL_FRAMESRC_HASH_RX:
                     if(em[i]->type == HASH_URL_FRAMESRC_HASH_RX)   {
                         rc = msc_regexec_capture(em[i]->param_data, link, strlen(link), ovector, 30, &my_error_msg);
-#ifdef WITH_PCRE2
+#ifndef WITH_PCRE
                         if ((rc == PCRE2_ERROR_MATCHLIMIT) || (rc == PCRE2_ERROR_RECURSIONLIMIT)) {
 #else
                         if ((rc == PCRE_ERROR_MATCHLIMIT) || (rc == PCRE_ERROR_RECURSIONLIMIT)) {
@@ -673,7 +672,7 @@ int do_hash_method(modsec_rec *msr, char *link, int type)   {
                                 msr_log(msr, 4, "%s.", error_msg);
                             return -1;
                         }
-#ifdef WITH_PCRE2
+#ifndef WITH_PCRE
                         if (rc != PCRE2_ERROR_NOMATCH) { /* Match. */
 #else
                         if (rc != PCRE_ERROR_NOMATCH) { /* Match. */
@@ -1079,22 +1078,18 @@ int inject_hashed_response_body(modsec_rec *msr, int elts) {
     if (ctype && encoding == NULL) {
         if (ctype && (p = m_strcasestr(ctype, "charset=") , p != NULL)) {
             p += 8 ;
-            if (encoding = apr_pstrndup(msr->mp, p, strcspn(p, " ;") ), encoding) {
-                xmlCharEncoding enc;
-                enc = xmlParseCharEncoding(encoding);
-                handler = xmlFindCharEncodingHandler(encoding);
-            }
+            encoding = apr_pstrndup(msr->mp, p, strcspn(p, " ;"));
+            handler = xmlFindCharEncodingHandler(encoding);
         }
     } else  {
         if(encoding != NULL)    {
-            xmlCharEncoding enc;
-            enc = xmlParseCharEncoding(encoding);
             handler = xmlFindCharEncodingHandler(encoding);
         }
     }
 
     if (msr->txcfg->debuglog_level >= 4)
-        msr_log(msr, 4, "inject_hashed_response_body: Detected encoding type [%s].", encoding);
+        msr_log(msr, 4, "inject_hashed_response_body: Detected encoding type [%s].",
+                encoding ? encoding : "(none)");
 
     if (handler == NULL)
         handler = xmlFindCharEncodingHandler("UTF-8");
