@@ -15,6 +15,7 @@
 #ifndef _UTIL_H_
 #define _UTIL_H_
 
+#include <assert.h>
 #include <sys/types.h>
 #include <apr_file_info.h>
 
@@ -159,4 +160,27 @@ int DSOLOCAL tree_contains_ip(apr_pool_t *mp, TreeRoot *rtree,
 int DSOLOCAL ip_tree_from_param(apr_pool_t *pool,
     char *param, TreeRoot **rtree, char **error_msg);
 
+#ifdef WITH_CURL
+int ip_tree_from_uri(TreeRoot **rtree, char *uri,
+    apr_pool_t *mp, char **error_msg);
+#endif
+
+char DSOLOCAL *get_username(apr_pool_t* mp);
+const char* id_log(msre_rule* rule);
+
+int read_line(char *buff, int size, FILE *fp);
+
+size_t msc_curl_write_memory_cb(void *contents, size_t size,
+    size_t nmemb, void *userp);
+
+struct msc_curl_memory_buffer_t
+{
+   char *memory;
+   size_t size;
+};
+
+#ifdef WIN32
+char *strtok_r(char *str, const char *delim, char **nextp);
+#endif
+
 #endif
