@@ -207,9 +207,13 @@ ngx_http_modsecurity_load_request(ngx_http_request_t *r)
 {
     ngx_http_modsecurity_ctx_t  *ctx;
     request_rec                 *req;
-    ngx_str_t                    str;
     size_t                       root;
     ngx_str_t                    path;
+    ngx_uint_t                   port;
+    struct sockaddr_in          *sin;
+#if (NGX_HAVE_INET6)
+    struct sockaddr_in6         *sin6;
+#endif
 
     ctx = ngx_http_get_module_ctx(r, ngx_http_modsecurity);
     req = ctx->req;
@@ -252,10 +256,30 @@ ngx_http_modsecurity_load_request(ngx_http_request_t *r)
     req->parsed_uri.path = (char *)ngx_pstrdup0(r->pool, &r->uri);
     req->parsed_uri.is_initialized = 1;
 
-    str.data = r->port_start;
-    str.len = r->port_end - r->port_start;
-    req->parsed_uri.port = ngx_atoi(str.data, str.len);
-    req->parsed_uri.port_str = (char *)ngx_pstrdup0(r->pool, &str);
+    switch (r->connection->local_sockaddr->sa_family) {
+
+#if (NGX_HAVE_INET6)
+    case AF_INET6:
+        sin6 = (struct sockaddr_in6 *) r->connection->local_sockaddr;
+        port = ntohs(sin6->sin6_port);
+        break;
+#endif
+
+#if (NGX_HAVE_UNIX_DOMAIN)
+    case AF_UNIX:
+        port = 0;
+        break;
+#endif
+
+    default: /* AF_INET */
+        sin = (struct sockaddr_in *) r->connection->local_sockaddr;
+        port = ntohs(sin->sin_port);
+        break;
+    }
+
+    req->parsed_uri.port = port;
+    req->parsed_uri.port_str = ngx_pnalloc(r->pool, sizeof("65535"));
+    (void) ngx_sprintf((u_char *)req->parsed_uri.port_str, "%ui%c", port, '\0');
 
     req->parsed_uri.query = r->args.len ? req->args : NULL;
     req->parsed_uri.dns_looked_up = 0;
@@ -528,9 +552,15 @@ ngx_http_modsecurity_save_request_body(ngx_http_request_t *r)
 
         hc = r->http_connection;
 
+#if defined(nginx_version) && nginx_version >= 1011011
+        if (hc->free && size == cscf->large_client_header_buffers.size) {
+
+            buf = hc->free->buf;
+#else
         if (hc->nfree && size == cscf->large_client_header_buffers.size) {
 
             buf = hc->free[--hc->nfree];
+#endif
 
             ngx_log_debug2(NGX_LOG_DEBUG_HTTP, r->connection->log, 0,
                            "ModSecurity: use http free large header buffer: %p %uz",
@@ -586,8 +616,6 @@ ngx_http_modsecurity_load_headers_out(ngx_http_request_t *r)
     ngx_http_modsecurity_ctx_t  *ctx;
     char                        *data;
     request_rec                 *req;
-    u_char                      *content_type;
-    ngx_uint_t                   content_type_len;
     ngx_http_variable_value_t   *vv;
     ngx_list_part_t             *part;
     ngx_table_elt_t             *h;
@@ -602,27 +630,6 @@ ngx_http_modsecurity_load_headers_out(ngx_http_request_t *r)
     req->status = r->headers_out.status;
     req->status_line = (char *)ngx_pstrdup0(r->pool, &r->headers_out.status_line);
 
-    if (r->headers_out.charset.len) {
-
-        content_type_len = r->headers_out.content_type.len
-                           + r->headers_out.charset.len
-                           + ngx_strlen("; charset=") + 1;
-
-        content_type = ngx_palloc(r->pool, content_type_len);
-
-        if (content_type == NULL) {
-            return NGX_ERROR;
-        }
-
-        ngx_snprintf(content_type, content_type_len,
-                     "%V; charset=%V\0",
-                     &r->headers_out.content_type,
-                     &r->headers_out.charset);
-
-        r->headers_out.content_type.data = content_type;
-        r->headers_out.content_type.len = content_type_len;
-    }
-
     /* deep copy */
     part = &r->headers_out.headers.part;
     h = part->elts;
@@ -719,6 +726,14 @@ ngx_http_modsecurity_save_headers_out(ngx_http_request_t *r)
     upstream = r->upstream;
     r->upstream = &ngx_http_modsecurity_upstream;
 
+    /* case SecServerSignature was used, the "Server: ..." header is added
+     * here, overwriting the default header supplied by nginx.
+     */
+    if (modsecIsServerSignatureAvailale() != NULL) {
+        apr_table_add(ctx->req->headers_out, "Server",
+                modsecIsServerSignatureAvailale());
+    }
+
     if (apr_table_do(ngx_http_modsecurity_save_headers_out_visitor,
                      r, ctx->req->headers_out, NULL) == 0) {
 
@@ -1019,6 +1034,10 @@ ngx_http_modsecurity_handler(ngx_http_request_t *r)
         return rc;
     }
 
+    if (modsecContextState(ctx->req) == MODSEC_DISABLED) {
+        return NGX_DECLINED;
+    }
+
     if (r->method == NGX_HTTP_POST 
             && modsecIsRequestBodyAccessEnabled(ctx->req) ) {
 
@@ -1074,8 +1093,6 @@ ngx_http_modsecurity_header_filter(ngx_http_request_t *r) {
     ngx_http_modsecurity_ctx_t      *ctx;
     const char                      *location;
     ngx_table_elt_t                 *h;
-    ngx_int_t                        rc;
-
 
     cf = ngx_http_get_module_loc_conf(r, ngx_http_modsecurity);
     ctx = ngx_http_get_module_ctx(r, ngx_http_modsecurity);
@@ -1112,36 +1129,6 @@ ngx_http_modsecurity_header_filter(ngx_http_request_t *r) {
 
     ngx_log_debug0(NGX_LOG_DEBUG_HTTP, r->connection->log, 0, "modSecurity: header filter");
 
-    /* header only or SecResponseBodyAccess off */
-    if (r->header_only || (!modsecIsResponseBodyAccessEnabled(ctx->req)) ) {
-
-        ctx->complete = 1;
-
-        if (ngx_http_modsecurity_load_headers_in(r) != NGX_OK
-                || ngx_http_modsecurity_load_headers_out(r) != NGX_OK) {
-
-            return NGX_HTTP_INTERNAL_SERVER_ERROR;
-        }
-
-        rc = ngx_http_modsecurity_status(r, modsecProcessResponse(ctx->req));
-
-        if (rc != NGX_DECLINED) {
-            return ngx_http_filter_finalize_request(r, &ngx_http_modsecurity, rc);
-        }
-
-        if (ngx_http_modsecurity_save_headers_in(r) != NGX_OK
-                || ngx_http_modsecurity_save_headers_out(r) != NGX_OK) {
-            return ngx_http_filter_finalize_request(r, &ngx_http_modsecurity, NGX_HTTP_INTERNAL_SERVER_ERROR);
-        }
-
-        return ngx_http_next_header_filter(r);
-    }
-
-    /* SecResponseBodyAccess on, process rules in body filter */
-
-    /* pretend we are ngx_http_header_filter */
-    r->header_sent = 1;
-
     r->filter_need_in_memory = 1;
     return NGX_OK;
 }
@@ -1376,6 +1363,10 @@ ngx_http_modsecurity_cleanup(void *data)
     if (ctx->req != NULL) {
         (void) modsecFinishRequest(ctx->req);
     }
+    if (ctx->connection != NULL) {
+        (void) modsecFinishConnection(ctx->connection);
+    }
+    
 }
 
     static char *
